You are viewing a plain text version of this content. The canonical link for it is here.
Posted to jira@kafka.apache.org by "Mickael Maison (Jira)" <ji...@apache.org> on 2023/04/17 08:52:00 UTC
[jira] [Commented] (KAFKA-14766) Improve performance of VarInt encoding/decoding
[ https://issues.apache.org/jira/browse/KAFKA-14766?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel&focusedCommentId=17712971#comment-17712971 ]
Mickael Maison commented on KAFKA-14766:
----------------------------------------
We're past feature freeze for 3.5.0 so moving to 3.6.0.
> Improve performance of VarInt encoding/decoding
> -----------------------------------------------
>
> Key: KAFKA-14766
> URL: https://issues.apache.org/jira/browse/KAFKA-14766
> Project: Kafka
> Issue Type: Improvement
> Components: core
> Reporter: Divij Vaidya
> Assignee: Divij Vaidya
> Priority: Major
> Fix For: 3.5.0
>
>
> Our current implementation in ByteUtils could be improved via loop unrolling and short circuiting scenarios such as 0.
> With the changes in attached PR, we see upto 83% improvement in throughput for writingVarInt.
--
This message was sent by Atlassian Jira
(v8.20.10#820010)